@@ -4,7 +4,7 @@
 """
    TODO Purpose of the file
    @project: HSPyLib
-   hspylib.app.firebase.src.main
+   @package: hspylib.app.firebase.src.main
       @file: __main__.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -21,12 +21,11 @@ from datetime import datetime
 from textwrap import dedent
 
 import urllib3
+from firebase.core.firebase import Firebase
 from hspylib.core.tools.commons import get_path, syserr
 from hspylib.modules.cli.application.application import Application
 from hspylib.modules.cli.application.version import AppVersion
 
-from firebase.core.firebase import Firebase
-
 # Disable this warning because we are hitting our own database
 urllib3.disable_warnings()
 
