@@ -4,7 +4,7 @@
 """
    TODO Purpose of the file
    @project: HSPyLib
-   hspylib.app.firebase.core
+   @package: hspylib.app.firebase.core
       @file: file_processor.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -20,14 +20,13 @@ from abc import ABC
 from fnmatch import fnmatch
 from typing import List, Union
 
+from firebase.entity.file_entry import FileEntry
 from hspylib.core.enums.http_code import HttpCode
 from hspylib.core.tools.commons import sysout
 from hspylib.core.tools.preconditions import check_argument, check_not_none, check_state
 from hspylib.modules.fetch.fetch import get, put
 from requests.exceptions import HTTPError
 
-from firebase.entity.file_entry import FileEntry
-
 
 class FileProcessor(ABC):
     """Utility class to upload and download B64 encoded files"""
