@@ -4,7 +4,7 @@
 """
    TODO Purpose of the file
    @project: HSPyLib
-   hspylib.app.firebase.core
+   @package: hspylib.app.firebase.core
       @file: firebase.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -18,10 +18,9 @@ import logging as log
 import os
 from typing import List
 
-from hspylib.core.tools.preconditions import check_argument
-
 from firebase.core.agent_config import AgentConfig
 from firebase.core.file_processor import FileProcessor
+from hspylib.core.tools.preconditions import check_argument
 
 
 class Firebase:
