@@ -4,7 +4,7 @@
 """
    TODO Purpose of the file
    @project: HSPyLib
-   hspylib.app.firebase.entity
+   @package: hspylib.app.firebase.entity
       @file: firebase_entry.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -18,9 +18,8 @@ import json
 from datetime import datetime
 from typing import List
 
-from hspylib.core.enums.charset import Charset
-
 from firebase.entity.file_entry import FileEntry
+from hspylib.core.enums.charset import Charset
 
 
 class FirebaseEntry:
